@@ -15,5 +15,12 @@
 #ifndef vtk_xdmf2_h
 #define vtk_xdmf2_h
 
+/* Use the xdmf2 library configured for VTK.  */
+#define VTK_MODULE_USE_EXTERNAL_vtkxdmf2 0
+
+#if VTK_MODULE_USE_EXTERNAL_vtkxdmf2
+#else
+#define VTKXDMF2_HEADER(x)  <vtkxdmf2/libsrc/x>
+#endif
 
 #endif
